@@ -1,15 +1,16 @@
-/* HMEPbcs.h -- This file is part of GNU/Archimedes release 0.0.3.
-   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+/* HMEPbcs.h -- This file is part of GNU/Archimedes release 0.1.0.
+   Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
-   of effective potential method.
+   of effective potential method. It is now able to simulate applied
+   magnetic fields along with self consistent Faraday equation.
 
    Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -18,14 +19,13 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-   USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 
 // ######################################################
 // Created on 26 Feb.2005, Siracusa, J.M.Sellier
-// Last modif. : 10 Aug.2007, Siracusa, J.M.Sellier
+// Last modif. : 09 Sep.2007, Siracusa, J.M.Sellier
 // ######################################################
 
 // Boundary Conditions for the Hybrid MEP model
@@ -78,11 +78,11 @@ HMEPBCs(void)
        u2d[i+2][1][3]=EDGE[0][i][2]*yvel;
        u2d[i+2][2][3]=EDGE[0][i][2]*yvel;
 // energy
-       u2d[i+2][0][4]=0.5*MSTAR[i_dom[i+2][0]][1]*M*yvel*yvel*EDGE[0][i][2]
+       u2d[i+2][0][4]=0.5*MSTAR[i_dom[i+2][3]][1]*M*yvel*yvel*EDGE[0][i][2]
                    +1.5*KB*TL*EDGE[0][i][2];
-       u2d[i+2][1][4]=0.5*MSTAR[i_dom[i+2][1]][1]*M*yvel*yvel*EDGE[0][i][2]
+       u2d[i+2][1][4]=0.5*MSTAR[i_dom[i+2][3]][1]*M*yvel*yvel*EDGE[0][i][2]
                    +1.5*KB*TL*EDGE[0][i][2];
-       u2d[i+2][2][4]=0.5*MSTAR[i_dom[i+2][2]][1]*M*yvel*yvel*EDGE[0][i][2]
+       u2d[i+2][2][4]=0.5*MSTAR[i_dom[i+2][3]][1]*M*yvel*yvel*EDGE[0][i][2]
                    +1.5*KB*TL*EDGE[0][i][2];
      }
    }
@@ -124,11 +124,11 @@ HMEPBCs(void)
        u2d[1][j+2][3]=0.;
        u2d[2][j+2][3]=0.;
 // energy
-       u2d[0][j+2][4]=0.5*MSTAR[i_dom[0][j+2]][1]*M*xvel*xvel*EDGE[3][j][2]
+       u2d[0][j+2][4]=0.5*MSTAR[i_dom[3][j+2]][1]*M*xvel*xvel*EDGE[3][j][2]
                    +1.5*KB*TL*EDGE[3][j][2];
-       u2d[1][j+2][4]=0.5*MSTAR[i_dom[1][j+2]][1]*M*xvel*xvel*EDGE[3][j][2]
+       u2d[1][j+2][4]=0.5*MSTAR[i_dom[3][j+2]][1]*M*xvel*xvel*EDGE[3][j][2]
                    +1.5*KB*TL*EDGE[3][j][2];
-       u2d[2][j+2][4]=0.5*MSTAR[i_dom[2][j+2]][1]*M*xvel*xvel*EDGE[3][j][2]
+       u2d[2][j+2][4]=0.5*MSTAR[i_dom[3][j+2]][1]*M*xvel*xvel*EDGE[3][j][2]
                    +1.5*KB*TL*EDGE[3][j][2];
      }
    }
@@ -170,11 +170,11 @@ HMEPBCs(void)
        u2d[nx+3][j+2][3]=0.;
        u2d[nx+4][j+2][3]=0.;
 // energy
-       u2d[nx+2][j+2][4]=0.5*MSTAR[i_dom[nx+2][j+2]][1]*M*xvel*xvel*EDGE[1][j][2]
+       u2d[nx+2][j+2][4]=0.5*MSTAR[i_dom[nx-1][j+2]][1]*M*xvel*xvel*EDGE[1][j][2]
                       +1.5*KB*TL*EDGE[1][j][2];
-       u2d[nx+3][j+2][4]=0.5*MSTAR[i_dom[nx+3][j+2]][1]*M*xvel*xvel*EDGE[1][j][2]
+       u2d[nx+3][j+2][4]=0.5*MSTAR[i_dom[nx-1][j+2]][1]*M*xvel*xvel*EDGE[1][j][2]
                       +1.5*KB*TL*EDGE[1][j][2];
-       u2d[nx+4][j+2][4]=0.5*MSTAR[i_dom[nx+4][j+2]][1]*M*xvel*xvel*EDGE[1][j][2]
+       u2d[nx+4][j+2][4]=0.5*MSTAR[i_dom[nx-1][j+2]][1]*M*xvel*xvel*EDGE[1][j][2]
                       +1.5*KB*TL*EDGE[1][j][2];
      }
    }
@@ -216,11 +216,11 @@ HMEPBCs(void)
        u2d[i+2][ny+3][3]=EDGE[2][i][2]*yvel;
        u2d[i+2][ny+4][3]=EDGE[2][i][2]*yvel;
 // energy
-       u2d[i+2][ny+2][4]=0.5*MSTAR[i_dom[i+2][ny+2]][1]*M*yvel*yvel*EDGE[2][i][2]
+       u2d[i+2][ny+2][4]=0.5*MSTAR[i_dom[i+2][ny-1]][1]*M*yvel*yvel*EDGE[2][i][2]
                       +1.5*KB*TL*EDGE[2][i][2];
-       u2d[i+2][ny+3][4]=0.5*MSTAR[i_dom[i+2][ny+3]][1]*M*yvel*yvel*EDGE[2][i][2]
+       u2d[i+2][ny+3][4]=0.5*MSTAR[i_dom[i+2][ny-1]][1]*M*yvel*yvel*EDGE[2][i][2]
                       +1.5*KB*TL*EDGE[2][i][2];
-       u2d[i+2][ny+4][4]=0.5*MSTAR[i_dom[i+2][ny+4]][1]*M*yvel*yvel*EDGE[2][i][2]
+       u2d[i+2][ny+4][4]=0.5*MSTAR[i_dom[i+2][ny-1]][1]*M*yvel*yvel*EDGE[2][i][2]
                       +1.5*KB*TL*EDGE[2][i][2];
      }
   }
