@@ -6,7 +6,8 @@
    potential method. It is now able to simulate applied
    magnetic fields along with self consistent Faraday equation.
 
-   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004, 2005, 2006, 2007, 2008 Jean Michel Sellier
+   <jeanmichel.sellier@gmail.com>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,9 +26,9 @@
 
 // =================================================================
 // File Name : archimedes.c
-// Version   : release 0.7.0
+// Version   : release 0.8.0
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 23 September 2007, Siracusa, Italy, Jean Michel Sellier.
+// Last Revision : 22 June 2008, Siracusa, Italy, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -237,7 +238,7 @@ Usage: %s [OPTION] file...\n",progname);
          your translation!
          no-wrap */
       printf ("\
-Report bugs to sellier@dmi.unict.it or archimedes@southnovel.eu\n");
+Report bugs to jeanmichel.sellier@gmail.com\n");
 
       exit (0);
     }
@@ -245,7 +246,7 @@ Report bugs to sellier@dmi.unict.it or archimedes@southnovel.eu\n");
   if (v)
     {
       /* Print version number.  */
-      printf("archimedes - GNU archimedes 0.7.0\n");
+      printf("archimedes - GNU archimedes 0.8.0\n");
       /* xgettext: no-wrap */
       printf("\n");
       printf("\
@@ -255,7 +256,7 @@ PARTICULAR PURPOSE.\n\
 You may redistribute copies of GNU %s under the terms\n\
 of the GNU General Public License.\n\
 For more information about these matters, see the file named COPYING.\n",
-              "2004, 2005, 2006, 2007","Archimedes");
+              "2004, 2005, 2006, 2007, 2008","Archimedes");
       exit (0);
     }
   else if (z){
